# From hadoop_vars.ps1
#
# Cluster Name and Subscription name
# $clusterName="<ClusterName>"
# $subscriptionName="<SubscriptionName>"
#
# Storage Account and Container
# $containerName = "<containerName>"
# $storageAccountName = "<StorageAccountName>"

Select-AzureSubscription -SubscriptionName $subscriptionName
Use-AzureHDInsightCluster -Name $clusterName

#   Assuming mahout-core-0.8-job.jar copied to Mahout folder.
$mahoutJob = New-AzureHDInsightMapReduceJobDefinition -JarFile "wasb://$containerName@$storageAccountName.blob.core.windows.net/mahout/mahout-core-0.8-job.jar" -ClassName "org.apache.mahout.cf.taste.hadoop.item.RecommenderJob"

# Adding the similarityclassname argument
$mahoutJob.Arguments.Add("-s")

# Adding the name of similarityclassname. However other similarityclassname can be used. 
$mahoutJob.Arguments.Add("SIMILARITY_COOCCURRENCE")

# Adding the input file argument
$mahoutJob.Arguments.Add("-i")

# Adding location of the file. The file is stored on Windows Azure Storage Blob.
$mahoutJob.Arguments.Add("wasb://$containerName@$storageAccountName.blob.core.windows.net/mahout/itemID.txt")

# Adding usersFile as an argument.
$mahoutJob.Arguments.Add("--usersFile")

# Adding userFile location.
$mahoutJob.Arguments.Add("wasb://$containerName@$storageAccountName.blob.core.windows.net/mahout/users.txt")

# Adding output as an argument.
$mahoutJob.Arguments.Add("--output")

# Adding output location. This will be the location where result will be generated.
$mahoutJob.Arguments.Add("wasb://$containerName@$storageAccountName.blob.core.windows.net/mahout/output")

# Starting job
$MahoutJobProcessing = Start-AzureHDInsightJob -Cluster $clusterName -JobDefinition $mahoutJob

# Waiting Job for completion
Wait-AzureHDInsightJob -Job $MahoutJobProcessing -WaitTimeoutInSeconds 3600

# Getting error if any
Get-AzureHDInsightJobOutput -Cluster $clusterName -JobId $MahoutJobProcessing.JobId -StandardError
