# WASB variables
# set in hadoop_vars.ps1
# $storageAccountName = "bobbmsdn"
# $containerName = "hadoop3"

# SQL database variables
# slightly different than sqoop_vars.ps1
$sqlDatabaseServer = "ta4ffcpj44"  
$sqlDatabaseLogin = "foo"
$sqlDatabaseLoginPassword = "Password1$"
$sqlDatabaseName = "test"  
$sqlDatabaseTableName = "log4jLogsCount"

# Oozie files for the tutorial  
$workflowDefinition = "C:\Scripts\DevWeek\Hadoop\OozieDemo\workflow.xml"
$hiveQLScript = "C:\Scripts\DevWeek\Hadoop\OozieDemo\useooziewf.hql"

# WASB folder for storing the Oozie tutorial files.
$destFolder = "tutorials/useoozie"  # Do NOT use the long path here

# Create a storage context object
$storageaccountkey = get-azurestoragekey $storageAccountName | %{$_.Primary}
$destContext = New-AzureStorageContext -StorageAccountName $storageAccountName -StorageAccountKey $storageaccountkey

function uploadOozieFiles()
{       
    Write-Host "Copy workflow definition and HiveQL script file ..." -ForegroundColor Green
    Set-AzureStorageBlobContent -File $workflowDefinition -Container $containerName -Blob "$destFolder/workflow.xml" -Context $destContext
    Set-AzureStorageBlobContent -File $hiveQLScript -Container $containerName -Blob "$destFolder/useooziewf.hql" -Context $destContext
}

function prepareHiveDataFile()
{
    Write-Host "Make a copy of the sample.log file ... " -ForegroundColor Green
    Start-CopyAzureStorageBlob -SrcContainer $containerName -SrcBlob "example/data/sample.log" -Context $destContext -DestContainer $containerName -destBlob "$destFolder/data/sample.log" -DestContext $destContext
}

function prepareSQLDatabase()
{
    # SQL query string for creating log4jLogsCount table
    $cmdCreateLog4jCountTable = " CREATE TABLE [dbo].[$sqlDatabaseTableName](
            [Level] [nvarchar](10) NOT NULL,
            [Total] float,
        CONSTRAINT [PK_$sqlDatabaseTableName] PRIMARY KEY CLUSTERED   
        (
        [Level] ASC
        )
        )"

    #Create the log4jLogsCount table
    Write-Host "Create Log4jLogsCount table ..." -ForegroundColor Green
    $conn = New-Object System.Data.SqlClient.SqlConnection
    $conn.ConnectionString = "Data Source=$sqlDatabaseServer.database.windows.net;Initial Catalog=$sqlDatabaseName;User ID=$sqlDatabaseLogin;Password=$sqlDatabaseLoginPassword;Encrypt=true;Trusted_Connection=false;"
    $conn.open()
    $cmd = New-Object System.Data.SqlClient.SqlCommand
    $cmd.connection = $conn
    $cmd.commandtext = $cmdCreateLog4jCountTable
    $cmd.executenonquery()

    $conn.close()
}

# upload workflow.xml, coordinator.xml, and ooziewf.hql
uploadOozieFiles;

# make a copy of example/data/sample.log to example/data/log4j/sample.log
prepareHiveDataFile;

# create log4jlogsCount table on SQL database
prepareSQLDatabase;