# Run WordCount sample

# Run the following commands to set the variables.
# see hadoop_vars.ps1 
# $subscriptionName = "<SubscriptionName>" 
# $clusterName = "<HDInsightClusterName>"        

# Make sure we're using the correct subscription
Select-AzureSubscription $subscriptionName

# Run the following commands to create a MapReduce job definition:
# Define the MapReduce job
# The hadoop-examples.jar file comes with the HDInsight cluster distribution. 
# There are two arguments for the MapReduce job. The first one is the source file name, and the second is the output file path. The source file comes with the HDInsight cluster distribution, and the output file path will be created at the run-time.
# The jar file is called hadoop-examples in V2.1, and hadoop-mapreduce-examples in V3

$wordCountJobDefinition = New-AzureHDInsightMapReduceJobDefinition -JarFile "wasb:///example/jars/hadoop-mapreduce-examples.jar" -ClassName "wordcount" -Arguments "wasb:///example/data/gutenberg/davinci.txt", "wasb:///example/data/WordCountOutput"
# $wordCountJobDefinition = New-AzureHDInsightMapReduceJobDefinition -JarFile "wasb:///example/jars/hadoop-examples.jar" -ClassName "wordcount" -Arguments "wasb:///example/data/gutenberg/davinci.txt", "wasb:///example/data/WordCountOutput"

# Submit the job
# In addition to the MapReduce job definition, you must also provide the HDInsight cluster name where you want to run the MapReduce job
$wordCountJob = Start-AzureHDInsightJob -Cluster $clusterName -JobDefinition $wordCountJobDefinition 

# The Start-AzureHDInsightJob is an asynchroized call. To check the completion of the job, use the Wait-AzureHDInsightJob cmdlet.
# Run the following command to check the completion of the MapReduce job:
Wait-AzureHDInsightJob -Job $wordCountJob -WaitTimeoutInSeconds 3600 

# Run the following command to check any errors with running the MapReduce job: 
# Get the job output
Get-AzureHDInsightJobOutput -Cluster $clusterName -JobId $wordCountJob.JobId -StandardError

